==> ejc-jlprogress-impl-3.0.0-20240726.015247-275-sources.jar: com/ejianc/business/jlprogress/quality/service/impl/SupplyConfirmServiceImpl.java <==
package com.ejianc.business.jlprogress.quality.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.jlprogress.quality.bean.SupplyConfirmDetailEntity;
import com.ejianc.business.jlprogress.quality.bean.SupplyDetailEntity;
import com.ejianc.business.jlprogress.quality.mapper.SupplyConfirmDetailMapper;
import com.ejianc.business.jlprogress.quality.mapper.SupplyDetailMapper;
import com.ejianc.business.jlprogress.quality.vo.MaterialPurchaseVO;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.jlprogress.quality.mapper.SupplyConfirmMapper;
import com.ejianc.business.jlprogress.quality.bean.SupplyConfirmEntity;
import com.ejianc.business.jlprogress.quality.service.ISupplyConfirmService;

import java.math.BigDecimal;
import java.util.*;

import static java.util.stream.Collectors.collectingAndThen;
import static java.util.stream.Collectors.toCollection;

/**
 * 质量检测-物资供货确认单-主表
 *
 * @author generator
 */
@Service("supplyConfirmService")
public class SupplyConfirmServiceImpl extends BaseServiceImpl<SupplyConfirmMapper, SupplyConfirmEntity> implements ISupplyConfirmService {


    @Override
    public List<MaterialPurchaseVO> materialPurchaseList(Page page, QueryWrapper wrapper) {
        List<MaterialPurchaseVO> list= baseMapper.materialPurchaseList(page,wrapper);
        return list;
    }
}

==> ejc-jlprogress-impl-3.0.0-20241016.094058-340-sources.jar: com/ejianc/business/jlprogress/quality/service/impl/SupplyConfirmServiceImpl.java <==
package com.ejianc.business.jlprogress.quality.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.jlprogress.quality.bean.SupplyConfirmDetailEntity;
import com.ejianc.business.jlprogress.quality.bean.SupplyDetailEntity;
import com.ejianc.business.jlprogress.quality.mapper.SupplyConfirmDetailMapper;
import com.ejianc.business.jlprogress.quality.mapper.SupplyDetailMapper;
import com.ejianc.business.jlprogress.quality.vo.MaterialPurchaseVO;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.jlprogress.quality.mapper.SupplyConfirmMapper;
import com.ejianc.business.jlprogress.quality.bean.SupplyConfirmEntity;
import com.ejianc.business.jlprogress.quality.service.ISupplyConfirmService;

import java.math.BigDecimal;
import java.util.*;

import static java.util.stream.Collectors.collectingAndThen;
import static java.util.stream.Collectors.toCollection;

/**
 * 质量检测-物资供货确认单-主表
 *
 * @author generator
 */
@Service("supplyConfirmService")
public class SupplyConfirmServiceImpl extends BaseServiceImpl<SupplyConfirmMapper, SupplyConfirmEntity> implements ISupplyConfirmService {



    @Override
    public List<MaterialPurchaseVO> materialPurchaseList(String startOfMonth, String endOfMonth,Integer pageIndex,Integer pageSize) {
        Integer realPageIndex=(pageIndex-1)*pageSize;
        List<MaterialPurchaseVO> list= baseMapper.materialPurchaseList(startOfMonth,endOfMonth,realPageIndex,pageSize);
        return list;
    }
}
